==> resin-4.0.32-src.tar.gz: resin-4.0.32/modules/resin/src/com/caucho/server/distcache/CacheBackupEngine.java <==
/*
 * Copyright (c) 1998-2012 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.server.distcache;

import java.io.InputStream;

import com.caucho.server.distcache.LocalDataManager.DataItem;
import com.caucho.util.HashKey;
import com.caucho.vfs.StreamSource;

/**
 * Backup for the distributed cache
 */
public interface CacheBackupEngine
{
  /**
   * Starts the service
   */
  public void start();
  
  public MnodeValue get(DistCacheEntry entry, CacheConfig config);

  public void put(byte []key, 
                  MnodeUpdate mnodeUpdate,
                  StreamSource valueStream);

  public void updateTime(byte []key, MnodeEntry mnodeValue);

  public void remove(byte []key, 
                     MnodeUpdate mnodeUpdate);
}

==> resin-4.0.52-src.tar.gz: resin-4.0.52/modules/resin/src/com/caucho/server/distcache/CacheBackupEngine.java <==
/*
 * Copyright (c) 1998-2012 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.server.distcache;

import com.caucho.vfs.StreamSource;

/**
 * Backup for the distributed cache
 */
public interface CacheBackupEngine
{
  /**
   * Starts the service
   */
  public void start();
  
  public MnodeValue get(DistCacheEntry entry);

  public void put(byte []key, 
                  byte []cacheHash,
                  MnodeUpdate mnodeUpdate,
                  StreamSource valueStream);

  public void updateTime(byte []key, MnodeEntry mnodeValue);

  public void remove(byte []key, byte []cacheHash,
                     MnodeUpdate mnodeUpdate);
}
